==> jc-1.4.0.tar.gz: java/nio/channels/ServerSocketChannel.h <==
// public abstract class java.nio.channels.ServerSocketChannel

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class b95b712f8b955018 java_nio_channels_SelectableChannel
// @dep_class bb82468336bc847b java_nio_channels_ServerSocketChannel
// @dep_class b39240b3676cb59b java_nio_channels_spi_AbstractInterruptibleChannel
// @dep_class 9d3bd8ebcf76e5ce java_nio_channels_spi_AbstractSelectableChannel

// header file dependencies
// @dep_header java_nio_channels_spi_AbstractSelectableChannel

#include "java/nio/channels/spi/AbstractSelectableChannel.h"

#ifndef _JC_java_nio_channels_ServerSocketChannel_H_
#define _JC_java_nio_channels_ServerSocketChannel_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_net_ServerSocket$object;
struct _jc_java_nio_channels_ServerSocketChannel$object;
struct _jc_java_nio_channels_SocketChannel$object;
struct _jc_java_nio_channels_spi_SelectorProvider$object;

// Typedefs
typedef struct _jc_java_nio_channels_ServerSocketChannel$sub_refs	_jc_java_nio_channels_ServerSocketChannel$sub_refs;
typedef struct _jc_java_nio_channels_ServerSocketChannel$sub_nonrefs	_jc_java_nio_channels_ServerSocketChannel$sub_nonrefs;
typedef struct _jc_java_nio_channels_ServerSocketChannel$refs	_jc_java_nio_channels_ServerSocketChannel$refs;
typedef struct _jc_java_nio_channels_ServerSocketChannel$nonrefs	_jc_java_nio_channels_ServerSocketChannel$nonrefs;
typedef struct _jc_java_nio_channels_ServerSocketChannel$object	_jc_java_nio_channels_ServerSocketChannel$object;

typedef const struct _jc_java_nio_channels_ServerSocketChannel$vmethods	_jc_java_nio_channels_ServerSocketChannel$vmethods;
typedef const struct _jc_java_nio_channels_ServerSocketChannel$vtable	_jc_java_nio_channels_ServerSocketChannel$vtable;
typedef const struct _jc_java_nio_channels_ServerSocketChannel$vtype	_jc_java_nio_channels_ServerSocketChannel$vtype;

// Constructors
extern void _jc_java_nio_channels_ServerSocketChannel$method$_init$21bbe82c9df5d674(_jc_env *, struct _jc_java_nio_channels_ServerSocketChannel$object *, struct _jc_java_nio_channels_spi_SelectorProvider$object *);

// Virtual methods
extern struct _jc_java_nio_channels_SocketChannel$object *_jc_java_nio_channels_ServerSocketChannel$method$accept$f9d2887ca9e9341b(_jc_env *, struct _jc_java_nio_channels_ServerSocketChannel$object *);
extern struct _jc_java_net_ServerSocket$object *_jc_java_nio_channels_ServerSocketChannel$method$socket$ca2d30a396954881(_jc_env *, struct _jc_java_nio_channels_ServerSocketChannel$object *);
extern jint _jc_java_nio_channels_ServerSocketChannel$method$validOps$2ee4dac018721573(_jc_env *, struct _jc_java_nio_channels_ServerSocketChannel$object *);

// Virtual method descriptors
extern _jc_method _jc_java_nio_channels_ServerSocketChannel$method_info$accept$f9d2887ca9e9341b;
extern _jc_method _jc_java_nio_channels_ServerSocketChannel$method_info$socket$ca2d30a396954881;
extern _jc_method _jc_java_nio_channels_ServerSocketChannel$method_info$validOps$2ee4dac018721573;

// Static methods
extern struct _jc_java_nio_channels_ServerSocketChannel$object *_jc_java_nio_channels_ServerSocketChannel$method$open$ab6ddedee87317ed(_jc_env *);

// Virtual methods structure
struct _jc_java_nio_channels_ServerSocketChannel$vmethods {
	struct _jc_java_nio_channels_SocketChannel$object	*(*accept$f9d2887ca9e9341b)(_jc_env *, struct _jc_java_nio_channels_ServerSocketChannel$object *);
	struct _jc_java_net_ServerSocket$object	*(*socket$ca2d30a396954881)(_jc_env *, struct _jc_java_nio_channels_ServerSocketChannel$object *);
	jint	(*validOps$2ee4dac018721573)(_jc_env *, struct _jc_java_nio_channels_ServerSocketChannel$object *);
};

// Vtable
struct _jc_java_nio_channels_ServerSocketChannel$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_nio_channels_spi_AbstractInterruptibleChannel$vmethods	java_nio_channels_spi_AbstractInterruptibleChannel;
	_jc_java_nio_channels_SelectableChannel$vmethods	java_nio_channels_SelectableChannel;
	_jc_java_nio_channels_spi_AbstractSelectableChannel$vmethods	java_nio_channels_spi_AbstractSelectableChannel;
	_jc_java_nio_channels_ServerSocketChannel$vmethods	java_nio_channels_ServerSocketChannel;
};

// Vtype
struct _jc_java_nio_channels_ServerSocketChannel$vtype {
	_jc_type			type;
	_jc_java_nio_channels_ServerSocketChannel$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_nio_channels_ServerSocketChannel$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_nio_channels_ServerSocketChannel$refs {
    _jc_java_nio_channels_ServerSocketChannel$sub_refs	java_nio_channels_ServerSocketChannel;
    _jc_java_nio_channels_spi_AbstractSelectableChannel$sub_refs	java_nio_channels_spi_AbstractSelectableChannel;
    _jc_java_nio_channels_SelectableChannel$sub_refs	java_nio_channels_SelectableChannel;
    _jc_java_nio_channels_spi_AbstractInterruptibleChannel$sub_refs	java_nio_channels_spi_AbstractInterruptibleChannel;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_nio_channels_ServerSocketChannel$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_nio_channels_ServerSocketChannel$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_nio_channels_spi_AbstractInterruptibleChannel$sub_nonrefs	java_nio_channels_spi_AbstractInterruptibleChannel;
    _jc_java_nio_channels_SelectableChannel$sub_nonrefs	java_nio_channels_SelectableChannel;
    _jc_java_nio_channels_spi_AbstractSelectableChannel$sub_nonrefs	java_nio_channels_spi_AbstractSelectableChannel;
    _jc_java_nio_channels_ServerSocketChannel$sub_nonrefs	java_nio_channels_ServerSocketChannel;
};

// Object instance structure
struct _jc_java_nio_channels_ServerSocketChannel$object {
	_jc_java_nio_channels_ServerSocketChannel$refs	refs[0];
	_jc_word		lockword;
	_jc_java_nio_channels_ServerSocketChannel$vtype	*vtype;
	_jc_java_nio_channels_ServerSocketChannel$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_nio_channels_ServerSocketChannel$vtype _jc_java_nio_channels_ServerSocketChannel$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_nio_channels_ServerSocketChannel, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_nio_channels_ServerSocketChannel$class_object;

#endif	/* _JC_java_nio_channels_ServerSocketChannel_H_ */

==> jc-1.4.6.tar.gz: java/nio/channels/ServerSocketChannel.h <==
// public abstract class java.nio.channels.ServerSocketChannel

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class b95b712f8b955018 java_nio_channels_SelectableChannel
// @dep_class bb82468336bc847b java_nio_channels_ServerSocketChannel
// @dep_class b39240b3676cb59b java_nio_channels_spi_AbstractInterruptibleChannel
// @dep_class 9d3bd8ebcf76e5ce java_nio_channels_spi_AbstractSelectableChannel

// header file dependencies
// @dep_header java_nio_channels_spi_AbstractSelectableChannel

#include "java/nio/channels/spi/AbstractSelectableChannel.h"

#ifndef _JC_java_nio_channels_ServerSocketChannel_H_
#define _JC_java_nio_channels_ServerSocketChannel_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_net_ServerSocket$object;
struct _jc_java_nio_channels_ServerSocketChannel$object;
struct _jc_java_nio_channels_SocketChannel$object;
struct _jc_java_nio_channels_spi_SelectorProvider$object;

// Typedefs
typedef struct _jc_java_nio_channels_ServerSocketChannel$sub_refs	_jc_java_nio_channels_ServerSocketChannel$sub_refs;
typedef struct _jc_java_nio_channels_ServerSocketChannel$sub_nonrefs	_jc_java_nio_channels_ServerSocketChannel$sub_nonrefs;
typedef struct _jc_java_nio_channels_ServerSocketChannel$refs	_jc_java_nio_channels_ServerSocketChannel$refs;
typedef struct _jc_java_nio_channels_ServerSocketChannel$nonrefs	_jc_java_nio_channels_ServerSocketChannel$nonrefs;
typedef struct _jc_java_nio_channels_ServerSocketChannel$object	_jc_java_nio_channels_ServerSocketChannel$object;

typedef const struct _jc_java_nio_channels_ServerSocketChannel$vmethods	_jc_java_nio_channels_ServerSocketChannel$vmethods;
typedef const struct _jc_java_nio_channels_ServerSocketChannel$vtable	_jc_java_nio_channels_ServerSocketChannel$vtable;
typedef const struct _jc_java_nio_channels_ServerSocketChannel$vtype	_jc_java_nio_channels_ServerSocketChannel$vtype;

// Constructors
extern void _jc_java_nio_channels_ServerSocketChannel$method$_init$21bbe82c9df5d674(_jc_env *, struct _jc_java_nio_channels_ServerSocketChannel$object *, struct _jc_java_nio_channels_spi_SelectorProvider$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_nio_channels_SocketChannel$object *_jc_java_nio_channels_ServerSocketChannel$method$accept$f9d2887ca9e9341b(_jc_env *, struct _jc_java_nio_channels_ServerSocketChannel$object *) _JC_JCNI_ATTR;
extern struct _jc_java_net_ServerSocket$object *_jc_java_nio_channels_ServerSocketChannel$method$socket$ca2d30a396954881(_jc_env *, struct _jc_java_nio_channels_ServerSocketChannel$object *) _JC_JCNI_ATTR;
extern jint _jc_java_nio_channels_ServerSocketChannel$method$validOps$2ee4dac018721573(_jc_env *, struct _jc_java_nio_channels_ServerSocketChannel$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_nio_channels_ServerSocketChannel$method_info$accept$f9d2887ca9e9341b;
extern _jc_method _jc_java_nio_channels_ServerSocketChannel$method_info$socket$ca2d30a396954881;
extern _jc_method _jc_java_nio_channels_ServerSocketChannel$method_info$validOps$2ee4dac018721573;

// Static methods
extern struct _jc_java_nio_channels_ServerSocketChannel$object *_jc_java_nio_channels_ServerSocketChannel$method$open$ab6ddedee87317ed(_jc_env *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_java_nio_channels_ServerSocketChannel$vmethods {
	struct _jc_java_nio_channels_SocketChannel$object	*(*accept$f9d2887ca9e9341b)(_jc_env *, struct _jc_java_nio_channels_ServerSocketChannel$object *) _JC_JCNI_ATTR;
	struct _jc_java_net_ServerSocket$object	*(*socket$ca2d30a396954881)(_jc_env *, struct _jc_java_nio_channels_ServerSocketChannel$object *) _JC_JCNI_ATTR;
	jint	(*validOps$2ee4dac018721573)(_jc_env *, struct _jc_java_nio_channels_ServerSocketChannel$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_nio_channels_ServerSocketChannel$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_nio_channels_spi_AbstractInterruptibleChannel$vmethods	java_nio_channels_spi_AbstractInterruptibleChannel;
	_jc_java_nio_channels_SelectableChannel$vmethods	java_nio_channels_SelectableChannel;
	_jc_java_nio_channels_spi_AbstractSelectableChannel$vmethods	java_nio_channels_spi_AbstractSelectableChannel;
	_jc_java_nio_channels_ServerSocketChannel$vmethods	java_nio_channels_ServerSocketChannel;
};

// Vtype
struct _jc_java_nio_channels_ServerSocketChannel$vtype {
	_jc_type			type;
	_jc_java_nio_channels_ServerSocketChannel$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_nio_channels_ServerSocketChannel$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_nio_channels_ServerSocketChannel$refs {
    _jc_java_nio_channels_ServerSocketChannel$sub_refs	java_nio_channels_ServerSocketChannel;
    _jc_java_nio_channels_spi_AbstractSelectableChannel$sub_refs	java_nio_channels_spi_AbstractSelectableChannel;
    _jc_java_nio_channels_SelectableChannel$sub_refs	java_nio_channels_SelectableChannel;
    _jc_java_nio_channels_spi_AbstractInterruptibleChannel$sub_refs	java_nio_channels_spi_AbstractInterruptibleChannel;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_nio_channels_ServerSocketChannel$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_nio_channels_ServerSocketChannel$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_nio_channels_spi_AbstractInterruptibleChannel$sub_nonrefs	java_nio_channels_spi_AbstractInterruptibleChannel;
    _jc_java_nio_channels_SelectableChannel$sub_nonrefs	java_nio_channels_SelectableChannel;
    _jc_java_nio_channels_spi_AbstractSelectableChannel$sub_nonrefs	java_nio_channels_spi_AbstractSelectableChannel;
    _jc_java_nio_channels_ServerSocketChannel$sub_nonrefs	java_nio_channels_ServerSocketChannel;
};

// Object instance structure
struct _jc_java_nio_channels_ServerSocketChannel$object {
	_jc_java_nio_channels_ServerSocketChannel$refs	refs[0];
	_jc_word		lockword;
	_jc_java_nio_channels_ServerSocketChannel$vtype	*vtype;
	_jc_java_nio_channels_ServerSocketChannel$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_nio_channels_ServerSocketChannel$vtype _jc_java_nio_channels_ServerSocketChannel$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_nio_channels_ServerSocketChannel, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_nio_channels_ServerSocketChannel$class_object;

#endif	/* _JC_java_nio_channels_ServerSocketChannel_H_ */
